pub enum RunnableKind {
Check,
Run,
TestOne,
TestMod,
DocTestOne,
BenchOne,
Flycheck,
Unknown,
}Expand description
The kind of runnable.
Variants
Check
cargo check, basically, with human-readable output.
Run
Can run a binary.
May include {label} which will get the label from the build section of a crate.
TestOne
Run a single test.
May include {label} which will get the label from the build section of a crate.
May include {test_id} which will get the test clicked on by the user.
TestMod
Run tests matching a pattern (in RA, usually a path::to::module::of::tests)
May include {label} which will get the label from the build section of a crate.
May include {test_pattern} which will get the test module clicked on by the user.
DocTestOne
Run a single doctest
May include {label} which will get the label from the build section of a crate.
May include {test_id} which will get the doctest clicked on by the user.
BenchOne
Run a single benchmark
May include {label} which will get the label from the build section of a crate.
May include {bench_id} which will get the benchmark clicked on by the user.
Flycheck
Template for checking a target, emitting rustc JSON diagnostics.
May include {label} which will get the label from the build section of a crate.
Unknown
For forwards-compatibility, i.e. old rust-analyzer binary with newer workspace discovery tools